SelectMessage class final

Inheritance

Constructors

SelectMessage(Message other, Map<String, Message> cases, int argIndex, [String? id])

Properties

argIndex → int
final
cases → Map<String, Message>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
finalinherited
other → Message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateString(List allArgs, {required PluralSelector pluralSelector, String cleaner(String p1)?, String? locale}) → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

type → const int