JsonDeserializer class

Inheritance

Constructors

JsonDeserializer(String data)

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageOffsets → List<int>
final
preamble ↔ JsonPreamble
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deserialize(PluralSelector selector) → MessageListJson
override
getMessage(dynamic message, [bool isTopLevel = false]) → Message
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited