JsonPreamble class

Inheritance

Constructors

JsonPreamble.build({required int serializationVersion, required String locale, required String hash, required bool hasIds})
JsonPreamble.parse(List _data)

Properties

hash → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hasIds → bool
no setteroverride
locale → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Iterable
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited