MessageListJson class

Inheritance

Constructors

MessageListJson(JsonPreamble _preamble, List<Message> messages, PluralSelector _selector, Map<int, int>? messageIndices)
MessageListJson.fromString(String string, PluralSelector intl)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageIndices → Map<int, int>?
final
messages → List<Message>
final
pluralSelector → PluralSelector
no setteroverride
preamble → Preamble
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateStringAtId(String id, List args) → String
override
generateStringAtIndex(int index, List args) → String
override
getIndex(int index) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited